==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/apprunner_service/ApprunnerServiceNetworkConfigurationOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.apprunner_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:51.617Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.apprunnerService.ApprunnerServiceNetworkConfigurationOutputReference")
public class ApprunnerServiceNetworkConfigurationOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected ApprunnerServiceNetworkConfigurationOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApprunnerServiceNetworkConfigurationOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ApprunnerServiceNetworkConfigurationOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putEgressConfiguration(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration value) {
        software.amazon.jsii.Kernel.call(this, "putEgressConfiguration", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetEgressConfiguration() {
        software.amazon.jsii.Kernel.call(this, "resetEgressConfiguration", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfigurationOutputReference getEgressConfiguration() {
        return software.amazon.jsii.Kernel.get(this, "egressConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfigurationOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration getEgressConfigurationInput() {
        return software.amazon.jsii.Kernel.get(this, "egressConfigurationInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfiguration getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfiguration.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfiguration value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/apprunner_service/ApprunnerServiceNetworkConfigurationOutputReference.java <==
package com.hashicorp.cdktf.providers.aws.apprunner_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:07.404Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.apprunnerService.ApprunnerServiceNetworkConfigurationOutputReference")
public class ApprunnerServiceNetworkConfigurationOutputReference extends com.hashicorp.cdktf.ComplexObject {

    protected ApprunnerServiceNetworkConfigurationOutputReference(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApprunnerServiceNetworkConfigurationOutputReference(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param terraformResource The parent resource. This parameter is required.
     * @param terraformAttribute The attribute on the parent resource this class is referencing. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ApprunnerServiceNetworkConfigurationOutputReference(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.IInterpolatingParent terraformResource, final @org.jetbrains.annotations.NotNull java.lang.String terraformAttribute) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(terraformResource, "terraformResource is required"), java.util.Objects.requireNonNull(terraformAttribute, "terraformAttribute is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putEgressConfiguration(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration value) {
        software.amazon.jsii.Kernel.call(this, "putEgressConfiguration", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * @param value This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void putIngressConfiguration(final @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration value) {
        software.amazon.jsii.Kernel.call(this, "putIngressConfiguration", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetEgressConfiguration() {
        software.amazon.jsii.Kernel.call(this, "resetEgressConfiguration", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void resetIngressConfiguration() {
        software.amazon.jsii.Kernel.call(this, "resetIngressConfiguration", software.amazon.jsii.NativeType.VOID);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfigurationOutputReference getEgressConfiguration() {
        return software.amazon.jsii.Kernel.get(this, "egressConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfigurationOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfigurationOutputReference getIngressConfiguration() {
        return software.amazon.jsii.Kernel.get(this, "ingressConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfigurationOutputReference.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration getEgressConfigurationInput() {
        return software.amazon.jsii.Kernel.get(this, "egressConfigurationInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationEgressConfiguration.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration getIngressConfigurationInput() {
        return software.amazon.jsii.Kernel.get(this, "ingressConfigurationInput", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfigurationIngressConfiguration.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfiguration getInternalValue() {
        return software.amazon.jsii.Kernel.get(this, "internalValue", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfiguration.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setInternalValue(final @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.apprunner_service.ApprunnerServiceNetworkConfiguration value) {
        software.amazon.jsii.Kernel.set(this, "internalValue", value);
    }
}
